var expect  = require('chai').expect;
var Request = require('request');
var OAuth   = require('../');

describe.skip("Twitter Personal Consumer", function() {
    var oauth = new OAuth({
        consumer: {
            public: 'sZT0SD2jf84lCdF8PWTLQ',
            secret: 'u25CRWvCpCB61ndpRHgiQ5EkioqNB7cPL43uQ3bk'
        },
        signature_method: 'HMAC-SHA1'
    });

    var token = {
        public: '61260444-Esv29YumfnPt4A7l5uyYWp6Sm6zJBMKmdY6kwLFH5',
        secret: 'gfNAhxRs9WjSfAtju570RRNTrbD1TyJNANq0cuYUoD7T9'
    };

    describe("#Get user timeline", function() {
        this.timeout(10000);

        var request = {
            url: 'https://api.twitter.com/1.1/statuses/user_timeline.json',
            method: 'GET'
        };

        it("should be an array of tweets", function(done) {
            Request({
                url: request.url,
                method: request.method,
                qs: oauth.authorize(request, token),
                json: true
            }, function(err, res, body) {
                expect(err).to.be.a('null');
                expect(body).to.be.an.instanceof(Array);
                done();
            });
        });
    });

    describe("#Get user timeline limit 5", function() {
        this.timeout(10000);

        var request = {
            url: 'https://api.twitter.com/1.1/statuses/user_timeline.json',
            method: 'GET',
            data: {
                count: 5
            }
        };

        it("should be an array of tweets (length 5)", function(done) {
            Request({
                url: request.url,
                method: request.method,
                qs: oauth.authorize(request, token),
                json: true
            }, function(err, res, body) {
                expect(err).to.be.a('null');
                expect(body).to.be.an.instanceof(Array);
                expect(body).to.have.length(5);
                done();
            });
        });
    });

    describe("#Get user timeline by header", function() {
        this.timeout(10000);

        var request = {
            url: 'https://api.twitter.com/1.1/statuses/user_timeline.json',
            method: 'GET'
        };

        it("should be an array of tweets", function(done) {
            Request({
                url: request.url,
                method: request.method,
                qs: request.data,
                headers: oauth.toHeader(oauth.authorize(request, token)),
                json: true
            }, function(err, res, body) {
                expect(err).to.be.a('null');
                expect(body).to.be.an.instanceof(Array);
                done();
            });
        });
    });

    describe.skip("#Tweet", function() {
        this.timeout(10000);

        var text = 'Testing oauth-1.0a';

        var request = {
            url: 'https://api.twitter.com/1.1/statuses/update.json',
            method: 'POST',
            data: {
                status: text
            }
        };

        it("should be an success object", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: oauth.authorize(request, token),
                json: true
            }, function(err, res, body) {
                expect(body).to.have.property('entities');
                expect(body).to.have.property('created_at');
                expect(body).to.have.property('id');
                expect(body).to.have.property('text');
                expect(body.text).to.equal(text);
                expect(body.user).to.be.an('object');
                done();
            });
        });
    });

    describe.skip("#Tweet by header", function() {
        this.timeout(10000);

        var text = 'Testing oauth-1.0a';

        var request = {
            url: 'https://api.twitter.com/1.1/statuses/update.json',
            method: 'POST',
            data: {
                status: text
            }
        };

        it("should be an success object", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: request.data,
                headers: oauth.toHeader(oauth.authorize(request, token)),
                json: true
            }, function(err, res, body) {
                expect(body).to.have.property('entities');
                expect(body).to.have.property('created_at');
                expect(body).to.have.property('id');
                expect(body).to.have.property('text');
                expect(body.text).to.equal(text);
                expect(body.user).to.be.an('object');
                done();
            });
        });
    });
});

describe.skip("Flickr Personal Consumer", function() {
    this.timeout(10000);

    var oauth = new OAuth({
        consumer: {
            public: 'a47d94cd0d49c24aa14e6bb3b06db5e4',
            secret: 'fac91663631aaaf9'
        },
        signature_method: 'HMAC-SHA1'
    });

    describe.skip("#Request Token", function() {
        var request = {
            url: 'http://www.flickr.com/services/oauth/request_token',
            method: 'POST',
            data: {
                oauth_callback: 'http://www.ddo.me'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: oauth.authorize(request)
            }, function(err, res, body) {
                expect(body).to.be.a('string');

                body = oauth.deParam(body);

                expect(body).to.have.property('oauth_callback_confirmed', 'true');
                expect(body).to.have.property('oauth_token');
                expect(body).to.have.property('oauth_token_secret');

                done();
            });
        });
    });

    describe.skip("#Request Token by Header", function() {
        var request = {
            url: 'http://www.flickr.com/services/oauth/request_token',
            method: 'POST',
            data: {
                oauth_callback: 'http://www.ddo.me'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: request.data,
                headers: oauth.toHeader(oauth.authorize(request))
            }, function(err, res, body) {
                expect(body).to.be.a('string');

                body = oauth.deParam(body);

                expect(body).to.have.property('oauth_callback_confirmed', 'true');
                expect(body).to.have.property('oauth_token');
                expect(body).to.have.property('oauth_token_secret');

                console.log(body);
                console.log('http://www.flickr.com/services/oauth/authorize?oauth_token=' + token.public);

                done();
            });
        });
    });
    
    /*
        Need to get token from Request Token
        And oauth_verifier after pass authorize on website
    */
    describe.skip("#Access Token", function() {
        //this token get from Request Token
        var token = {
            public: '72157639916605676-87bf560d10e0866e',
            secret: 'ff89df792ef7e432'
        };

        var request = {
            url: 'http://www.flickr.com/services/oauth/access_token',
            method: 'POST',
            data: {
                oauth_verifier: '9d692ee8b8aa638d'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: oauth.authorize(request, token)
            }, function(err, res, body) {
                expect(body).to.be.a('string');

                body = oauth.deParam(body);

                expect(body).to.have.property('fullname');
                expect(body).to.have.property('user_nsid');
                expect(body).to.have.property('username');
                expect(body).to.have.property('oauth_token');
                expect(body).to.have.property('oauth_token_secret');

                token.public = body.oauth_token;
                token.secret = body.oauth_token_secret;

                console.log(token);
                console.log(body);

                done();
            });
        });
    });
    
    /*
        Need to get token from Access Token
    */
    describe("#flickr.test.login", function() {
        var token = {
            public: '72157639924000864-a9d73f3d1d30cd85',
            secret: 'e6e4e296a0bb6adb'
        };

        var request = {
            url: 'http://api.flickr.com/services/rest/?method=flickr.test.login',
            method: 'GET',
            data: {
                api_key: token.public,
                format: 'json'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                qs: oauth.authorize(request, token)
            }, function(err, res, body) {
                expect(body).to.be.a('string');
                expect(body).to.have.string('jsonFlickrApi');
                done();
            });
        });
    });

    /*
        Need to get token from Access Token
    */
    describe("#flickr.test.null", function() {
        var token = {
            public: '72157639924000864-a9d73f3d1d30cd85',
            secret: 'e6e4e296a0bb6adb'
        };

        var request = {
            url: 'http://api.flickr.com/services/rest/?method=flickr.test.null',
            method: 'GET',
            data: {
                api_key: token.public,
                format: 'json'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                qs: oauth.authorize(request, token)
            }, function(err, res, body) {
                expect(body).to.be.a('string');
                expect(body).to.have.string('jsonFlickrApi');
                console.log(body);
                done();
            });
        });
    });
});

describe.skip("Bitbucket Personal Consumer", function() {
    this.timeout(10000);

    var oauth = new OAuth({
        consumer: {
            public: 'pQ5uxrt3demLPN8s8q',
            secret: 'STZwykSSKzazP7fdxjDVfqfnABTTczWn'
        },
        signature_method: 'HMAC-SHA1'
    });

    describe("#Request Token", function() {
        var request = {
            url: 'https://bitbucket.org/api/1.0/oauth/request_token',
            method: 'POST',
            data: {
                oauth_callback: 'http://www.ddo.me'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: oauth.authorize(request)
            }, function(err, res, body) {
                expect(body).to.be.a('string');

                body = oauth.deParam(body);

                expect(body).to.have.property('oauth_callback_confirmed', 'true');
                expect(body).to.have.property('oauth_token');
                expect(body).to.have.property('oauth_token_secret');

                done();
            });
        });
    });

    describe("#Request Token by Header", function() {
        var request = {
            url: 'https://bitbucket.org/api/1.0/oauth/request_token',
            method: 'POST',
            data: {
                oauth_callback: 'http://www.ddo.me'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: request.data,
                headers: oauth.toHeader(oauth.authorize(request))
            }, function(err, res, body) {
                expect(body).to.be.a('string');

                body = oauth.deParam(body);

                expect(body).to.have.property('oauth_callback_confirmed', 'true');
                expect(body).to.have.property('oauth_token');
                expect(body).to.have.property('oauth_token_secret');

                console.log(body);
                done();
            });
        });
    });
});

/*
    Can not use Header
*/
describe.skip("Linkedin Personal Consumer", function() {
    this.timeout(10000);

    var oauth = new OAuth({
        consumer: {
            public: 'zbud5q8h0eac',
            secret: 'BCdXJ6G9sydJqBFC'
        },
        signature_method: 'HMAC-SHA1'
    });

    describe("#Request Token", function() {
        var request = {
            url: 'https://api.linkedin.com/uas/oauth/requestToken',
            method: 'POST',
            data: {
                oauth_callback: 'http://www.ddo.me'
            }
        };

        it("should be a valid response", function(done) {
            Request({
                url: request.url,
                method: request.method,
                form: oauth.authorize(request)
            }, function(err, res, body) {
                expect(body).to.be.a('string');

                body = oauth.deParam(body);

                expect(body).to.have.property('oauth_callback_confirmed', 'true');
                expect(body).to.have.property('oauth_token');
                expect(body).to.have.property('oauth_token_secret');

                done();
            });
        });
    });
});